@@ -15,7 +15,7 @@ import multiprocessing
 import os
 import pathlib
 import re
-from typing import List
+from typing import ClassVar, List
 
 import runez
 from runez.http import RestClient
@@ -24,7 +24,6 @@ from runez.render import Header, PrettyTable
 
 from portable_python.versions import PPG
 
-
 LOG = logging.getLogger(__name__)
 RX_BINARY = re.compile(r"^.*\.(dylib|gmo|icns|ico|nib|prof.*|tar)$")
 
@@ -36,11 +35,16 @@ def is_binary_file(path):
 def patch_folder(folder, regex, replacement, ignore=None):
     """Replace all occurrences of 'old_text' by 'new_text' in all files in 'folder'
 
-    Args:
-        folder (pathlib.Path): Folder to scan
-        regex: Regex to replace
-        replacement (str): Replacement text
-        ignore: Regex stating what to ignore
+    Parameters
+    ----------
+    folder : pathlib.Path
+        Folder to scan
+    regex : str
+        Regex to replace
+    replacement : str
+        Replacement text
+    ignore : re.Pattern | None
+        Regex stating what to ignore
     """
     for path in runez.ls_dir(folder):
         if not path.is_symlink() and (not ignore or not ignore.match(path.name)):
@@ -53,21 +57,21 @@ def patch_folder(folder, regex, replacement, ignore=None):
 
 def patch_file(path, regex, replacement):
     try:
-        with open(path, "rt") as fh:
+        with open(path) as fh:
             text = fh.read()
 
         new_text = re.sub(regex, replacement, text, flags=re.MULTILINE)
         if text != new_text:
-            with open(path, "wt") as fh:
+            with open(path, "w") as fh:
                 fh.write(new_text)
 
-            LOG.info("Patched '%s' in %s" % (regex, runez.short(path)))
+            LOG.info("Patched '%s' in %s", regex, runez.short(path))
 
     except Exception as e:
-        with open(path, "rt", errors="ignore") as fh:
+        with open(path, errors="ignore") as fh:
             text = fh.read()
             if re.search(regex, text):
-                LOG.warning("Can't patch '%s': %s" % (runez.short(path), e))
+                LOG.warning("Can't patch '%s': %s", runez.short(path), e)
 
 
 class FolderMask:
@@ -81,7 +85,7 @@ class FolderMask:
     """
 
     def __init__(self, target_folder):
-        LOG.info("Applying isolation hack/mask to %s" % target_folder)
+        LOG.info("Applying isolation hack/mask to %s", target_folder)
         self.target_folder = target_folder
         r = runez.run("hdiutil", "attach", "-nomount", "ram://2048", fatal=Exception)
         self.ram_disk = r.output.strip()
@@ -93,7 +97,7 @@ class FolderMask:
         self.mounted = True
 
     def cleanup(self):
-        LOG.info("Cleaning up isolation hack/mask for %s" % self.target_folder)
+        LOG.info("Cleaning up isolation hack/mask for %s", self.target_folder)
         if self.mounted:
             runez.run("umount", self.target_folder, fatal=False)
 
@@ -118,8 +122,12 @@ class BuildContext:
 
     def _resolved_isolation(self):
         """
-        Returns:
-            (str | None): What strategy to use to work around the fact that python's ./configure script looks at /usr/local
+        Isolation setting currently configured.
+
+        Returns
+        -------
+        str | None
+            What strategy to use to work around the fact that python's ./configure script looks at /usr/local
         """
         v = PPG.config.get_value("isolate-usr-local")
         if v == "auto":
@@ -182,7 +190,7 @@ class BuildContext:
 
 class BuildSetup:
     """
-    This class drives the compilation, external modules first, then the target python itself.
+    Drives the compilation, external modules first, then the target python itself.
     All modules are compiled in the same manner, follow the same conventional build layout.
     """
 
@@ -191,10 +199,14 @@ class BuildSetup:
 
     def __init__(self, python_spec=None, modules=None, prefix=None):
         """
-        Args:
-            python_spec (str | PythonSpec | None): Python to build (family and version)
-            modules (str | None): Modules to build (default: from config)
-            prefix (str | None): --prefix to use
+        Parameters
+        ----------
+        python_spec : str | PythonSpec | None
+            Python to build (family and version)
+        modules : str | None
+            Modules to build (default: from config)
+        prefix : str | None
+            --prefix to use
         """
         if not python_spec or python_spec == "latest":
             python_spec = PPG.cpython.latest
@@ -267,11 +279,11 @@ class BuildSetup:
         with BuildContext(self) as build_context:
             self.build_context = build_context
             modules = self.python_builder.modules
-            LOG.info("portable-python v%s, current folder: %s" % (runez.get_version(__name__), os.getcwd()))
+            LOG.info("portable-python v%s, current folder: %s", runez.get_version(__name__), os.getcwd())
             LOG.info(runez.joined(modules, list(modules)))
             LOG.info(PPG.config.config_files_report())
-            LOG.info("Platform: %s" % PPG.target)
-            LOG.info("Build report:\n%s" % self.python_builder.modules.report())
+            LOG.info("Platform: %s", PPG.target)
+            LOG.info("Build report:\n%s", self.python_builder.modules.report())
             self.validate_module_selection(fatal=not runez.DRYRUN and not self.x_debug)
             self.ensure_clean_folder(self.folders.components)
             self.ensure_clean_folder(self.folders.deps)
@@ -375,7 +387,6 @@ class ModuleCollection:
 
 
 class LinkerOutcome(enum.Enum):
-
     absent = "orange"
     failed = "red"
     shared = "blue"
@@ -389,6 +400,7 @@ class ModuleBuilder:
     m_build_cwd: str = None  # Optional: relative (to unpacked source) folder where to run configure/make from
     m_debian = None
     m_include: str = None  # Optional: subfolder to automatically list in CPATH when this module is active
+    m_telltale: ClassVar[list]  # Optional: list of files that, if present, indicate this module is installed
 
     setup: BuildSetup
     parent_module: "ModuleBuilder" = None
@@ -396,8 +408,10 @@ class ModuleBuilder:
 
     def __init__(self, parent_module):
         """
-        Args:
-            parent_module (BuildSetup | ModuleBuilder): Associated parent
+        Parameters
+        ----------
+        parent_module : BuildSetup | ModuleBuilder
+            Associated parent
         """
         self.m_name = ModuleCollection.get_module_name(self.__class__)
         if isinstance(parent_module, BuildSetup):
@@ -458,7 +472,7 @@ class ModuleBuilder:
         if self.resolved_telltale:
             return "has %s" % self.resolved_telltale
 
-        return "no %s" % getattr(self, "m_telltale")
+        return "no %s" % self.m_telltale
 
     def _find_telltale(self):
         telltales = getattr(self, "m_telltale", runez.UNSET)
@@ -525,8 +539,7 @@ class ModuleBuilder:
 
     def run_configure(self, program, *args, prefix=None):
         """
-        Calling ./configure is similar across all components.
-        This allows to have descendants customize each part relatively elegantly
+        Run ./configure script for this module.
         """
         if prefix is None:
             prefix = self.deps
@@ -564,7 +577,8 @@ class ModuleBuilder:
             yield
 
         except Exception as e:
-            LOG.error("Error while compiling %r: %r", self, e)
+            overview = repr(e)
+            LOG.exception("Error while compiling %s: %s", self, overview)
             raise
 
         finally:
@@ -598,7 +612,7 @@ class ModuleBuilder:
                 env_vars = self._get_env_vars()
                 prev_env_vars = {}
                 for var_name, value in env_vars.items():
-                    LOG.info("env %s=%s" % (var_name, runez.short(value, size=2048)))
+                    LOG.info("env %s=%s", var_name, runez.short(value, size=2048))
                     prev_env_vars[var_name] = os.environ.get(var_name)
                     os.environ[var_name] = value
 
@@ -672,7 +686,6 @@ class ModuleBuilder:
 
 
 class PythonBuilder(ModuleBuilder):
-
     _bin_python: pathlib.Path = None
 
     def __init__(self, parent_module):
@@ -692,8 +705,10 @@ class PythonBuilder(ModuleBuilder):
     @property
     def bin_python(self):
         """
-        Returns:
-            (pathlib.Path | None): Path to freshly compiled bin/python, real file (not symlink)
+        Returns
+        -------
+            pathlib.Path | None
+                Path to freshly compiled bin/python, real file (not symlink)
         """
         if self._bin_python is None:
             self._bin_python = PPG.config.find_main_file(self.bin_folder / "python", self.version)
@@ -724,5 +739,5 @@ class PythonBuilder(ModuleBuilder):
                 expected = 0o755 if path.is_dir() else 0o644
                 current = path.stat().st_mode & 0o777
                 if current != expected:
-                    LOG.info("Corrected permissions for %s (was %s)" % (runez.short(path), oct(current)))
+                    LOG.info("Corrected permissions for %s (was %s)", runez.short(path), oct(current))
                     path.chmod(expected)
