@@ -9,7 +9,6 @@ import runez
 import yaml
 from runez.pyenv import Version
 
-
 LOG = logging.getLogger(__name__)
 
 DEFAULT_CONFIG = """
@@ -79,9 +78,12 @@ class Config:
 
     def __init__(self, paths=None, target=None):
         """
-        Args:
-            paths (str | list | None): Path(s) to config file(s)
-            target (str | runez.system.PlatformId | None): Target platform (for testing, defaults to current platform)
+        Parameters
+        ----------
+        paths : str | list | None
+            Path(s) to config file(s)
+        target : str | runez.system.PlatformId | None
+            Target platform (for testing, defaults to current platform)
         """
         self.paths = runez.flattened(paths, split=",")
         if not isinstance(target, runez.system.PlatformId):
@@ -98,17 +100,21 @@ class Config:
         return "%s [%s]" % (runez.plural(self._sources, "config source"), self.target)
 
     def completions(self, **given):
-        res = dict(arch=self.target.arch, platform=self.target.platform, subsystem=self.target.subsystem, target=str(self.target))
+        res = {"arch": self.target.arch, "platform": self.target.platform, "subsystem": self.target.subsystem, "target": str(self.target)}
         res.update(given)
         return res
 
     def get_value(self, *key, by_platform=True):
         """
-        Args:
-            key (str | tuple): Key to look up, tuple represents hierarchy, ie: a/b -> (a, b)
-            by_platform (bool): If True, value can be configured by platform
+        Parameters
+        ----------
+        key : strzz | tuple
+            Key to look up, tuple represents hierarchy, ie: a/b -> (a, b)
+        by_platform : bool
+            If True, value can be configured by platform
 
-        Returns:
+        Returns
+        -------
             Associated value, if any
         """
         value, _ = self.get_entry(*key, by_platform=by_platform)
@@ -116,18 +122,23 @@ class Config:
 
     def get_entry(self, *key, by_platform=True):
         """
-        Args:
-            key (str | tuple): Key to look up, tuple represents hierarchy, ie: a/b -> (a, b)
-            by_platform (bool): If True, value can be configured by platform
+        Parameters
+        ----------
+        key : str | tuple
+            Key to look up, tuple represents hierarchy, ie: a/b -> (a, b)
+        by_platform : bool
+            If True, value can be configured by platform
 
-        Returns:
-            Associated value, if any
+        Returns
+        -------
+        (str | int | float | bool | dict | list | None, ConfigSource | None)
+            Associated value (if any), together with the source that defined it
         """
         if by_platform:
             keys = (self.target.platform, self.target.arch, *key), (self.target.platform, *key), key
 
         else:
-            keys = (key, )
+            keys = (key,)
 
         for k in keys:
             for source in self._sources:
@@ -150,7 +161,7 @@ class Config:
         return value
 
     def config_files_report(self):
-        """One liner describing which config files are used, if any"""
+        """One-liner describing which config files are used, if any"""
         if len(self._sources) > 1:
             return "Config files: %s" % runez.joined(self._sources[:-1], delimiter=", ")
 
@@ -174,7 +185,7 @@ class Config:
     def delete(path):
         size = runez.filesize(path)
         runez.delete(path, logger=None)
-        LOG.info("Deleted %s (%s)" % (runez.short(path), runez.represented_bytesize(size)))
+        LOG.info("Deleted %s (%s)", runez.short(path), runez.represented_bytesize(size))
         return size
 
     @staticmethod
@@ -185,20 +196,38 @@ class Config:
         except Exception as e:
             runez.abort("Invalid yaml in %s: %s" % (runez.bold(runez.short(source)), e))
 
-    def cleanup_folder(self, module, *clean_key):
+    def cleanup_configured_globs(self, title, module, *keys):
         """
-        Args:
-            module (portable_python.PythonBuilder): Associated python builder module
-            *clean_key: Config keys to lookup
+        Parameters
+        ----------
+        title : str
+            Title to use in log messages
+        module : portable_python.PythonBuilder
+            Associated python builder module
+        *keys : str
+            Config keys to lookup
         """
-        spec = [(x, f"{x}-{self.target.platform}") for x in clean_key]
-        spec = runez.flattened(spec, transform=self.get_value)
-        spec = runez.flattened(spec, split=True, unique=True)
-        if spec:
-            spec = [module.setup.folders.formatted(x) for x in spec]
+        globs = [(x, f"{x}-{self.target.platform}") for x in keys]
+        globs = runez.flattened(globs, transform=self.get_value)
+        globs = runez.flattened(globs, split=True, unique=True)
+        self.cleanup_globs(title, module, *globs)
+
+    def cleanup_globs(self, title, module, *globs):
+        """
+        Parameters
+        ----------
+        title : str
+            Title to use in log messages
+        module : portable_python.PythonBuilder
+            Associated python builder module
+        *globs : str
+            Glob patterns to clean up
+        """
+        if globs:
+            spec = [module.setup.folders.formatted(x) for x in globs]
             deleted_size = 0
             matcher = FileMatcher(spec)
-            LOG.info("Applying clean-up spec: %s" % matcher)
+            LOG.info("Applying clean-up spec: %s", matcher)
             cleaned = []
             for dirpath, dirnames, filenames in os.walk(module.install_folder):
                 removed = []
@@ -222,7 +251,8 @@ class Config:
             if cleaned:
                 names = runez.joined(sorted(set(cleaned)))
                 deleted_size = runez.represented_bytesize(deleted_size)
-                LOG.info("Cleaned %s (%s): %s" % (runez.plural(cleaned, "build artifact"), deleted_size, runez.short(names)))
+                count = runez.plural(cleaned, "build artifact")
+                LOG.info("%s: Cleaned %s (%s): %s", title, count, deleted_size, runez.short(names))
 
     def symlink_duplicates(self, folder):
         if self.target.is_linux or self.target.is_macos:
@@ -230,7 +260,7 @@ class Config:
             _find_file_duplicates(seen, folder)
             duplicates = {k: v for k, v in seen.items() if len(v) > 1}
             for dupes in duplicates.values():
-                LOG.info("Found duplicates: %s" % runez.joined(dupes, delimiter=", "))
+                LOG.info("Found duplicates: %s", runez.joined(dupes, delimiter=", "))
                 dupes = sorted(dupes, key=lambda x: len(str(x)))
                 if len(dupes) == 2:
                     shorter, longer = dupes
@@ -250,14 +280,19 @@ class Config:
         return basename, "%s%s" % (basename, version.major), "%s%s" % (basename, version.mm)
 
     @staticmethod
-    def find_main_file(desired: pathlib.Path, version: Version):
+    def find_main_file(desired, version):
         """
-        Args:
-            desired: Desired path (base name considered if path not directly available)
-            version: Associated version
+        Parameters
+        ----------
+        desired : pathlib.Path
+            Desired path (base name considered if path not directly available)
+        version : Version
+            Associated version
 
-        Returns:
-            (pathlib.Path | None): Path to associated real file (not symlink)
+        Returns
+        -------
+        pathlib.Path | None
+            Path to associated real file (not symlink)
         """
         p = Config.real_path(desired)
         if p:
@@ -324,10 +359,14 @@ class ConfigSource:
 
     def get_value(self, key):
         """
-        Args:
-            key (str | tuple): Key to look up, tuple represents hierarchy, ie: a/b -> (a, b)
+        Parameters
+        ----------
+        key : str | tuple
+            Key to look up, tuple represents hierarchy, ie: a/b -> (a, b)
 
-        Returns:
+        Returns
+        -------
+        str | int | float | bool | dict | list | None
             Associated value, if any
         """
         return self._deep_get(self.data, key)
@@ -349,7 +388,6 @@ class ConfigSource:
 
 
 class FileMatcher:
-
     def __init__(self, clean_spec):
         self.matches = []
         for spec in clean_spec:
@@ -365,7 +403,6 @@ class FileMatcher:
 
 
 class SingleFileMatch:
-
     _on_folder = False
     _rx_basename = None
     _rx_path = None
